@@ -6,5 +6,5 @@
 # stepp model         #
 #######################
 setClassUnion("stmodel",
-  c("stmodelGLM", "stmodelKM", "stmodelCI")
-)  
+  c("stmodelKM", "stmodelCI", "stmodelGLM")
+)
